@@ -17,7 +17,6 @@ PKGOUTPUT = PKGROOT.joinpath('outputs')
 os.environ['ROOT_PATH_FOR_DYNACONF'] = str(PKGROOT)
 logger.info(f"ROOT PATH ENVAR: {os.getenv('ROOT_PATH_FOR_DYNACONF')}")
 logger.info(f"WORKING ENV: {os.getenv('ENV_FOR_DYNACONF')}")
-logger.info(f"INCLUDED SETTINGS ENVAR: {os.getenv('INCLUDES_FOR_DYNACONF')}")
 # Enable setting config if used as a standalone module
 if '--config' in sys.argv:
     conf_path = sys.argv[sys.argv.index('--config') + 1]
@@ -25,7 +24,7 @@ if '--config' in sys.argv:
     assert config_path.exists(), f"Config file not found on path {config_path}"
     assert '.toml' in config_path.suffix, "Config files need to be a valid .toml file, see example."
     os.environ['SETTINGS_FILE_FOR_DYNACONF'] = str(config_path)
-logger.info(f"SETTINGS FILE ENVAR: {os.getenv('INCLUDES_FOR_DYNACONF')}")
+logger.info(f"INCLUDES FILE ENVAR: {os.getenv('INCLUDES_FOR_DYNACONF')}")
 # Load config from dynaconf. If importing module, ensure you set root path in envar.
 LOGPATH = Path(settings.LOGS).resolve()
 LOGGING = settings.LOGGING
@@ -49,7 +48,7 @@ __all__ = [
 
 
 def printconfig(varname, var):
-    logger.debug(f"__init__: Setting {varname} to {var}")
+    logger.info(f"__init__: Setting {varname} to {var}")
 
 
 # DEBUG logging enabled
