@@ -8,4 +8,4 @@ if __name__ == '__main__':
 
     Usage: python3 -m <packagename>
     """
-    kh.main()
+    print(kh.main())
